pub enum FactoryRequest {
CreateRealm {
payload: CreateRealmRequest,
responder: FactoryCreateRealmResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: FactoryControlHandle,
method_type: MethodType,
},
}Expand description
Factory creates isolated test realms. It wraps the underlying test harness infrastructure to simplify setup.
Variants
CreateRealm
Creates a new test realm configured with the given parameters and overrides.
Returns a RealmProxy that the client can use to start and introspect the realm.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: FactoryControlHandle
method_type: MethodTypeImplementations
Sourceimpl FactoryRequest
impl FactoryRequest
pub fn into_create_realm( self, ) -> Option<(CreateRealmRequest, FactoryCreateRealmResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL