pub struct FactoryProxy { /* private fields */ }Implementations
Sourceimpl FactoryProxy
impl FactoryProxy
Sourcepub fn take_event_stream(&self) -> FactoryEventStream
pub fn take_event_stream(&self) -> FactoryEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn create_realm(
&self,
payload: CreateRealmRequest,
) -> QueryResponseFut<FactoryCreateRealmResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn create_realm( &self, payload: CreateRealmRequest, ) -> QueryResponseFut<FactoryCreateRealmResult, DefaultFuchsiaResourceDialect> ⓘ
Creates a new test realm configured with the given parameters and overrides.
Returns a RealmProxy that the client can use to start and introspect the realm.