pub struct FactorySynchronousProxy { /* private fields */ }Implementations
Sourceimpl FactorySynchronousProxy
impl FactorySynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<FactoryEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<FactoryEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn create_realm(
&self,
payload: CreateRealmRequest,
___deadline: MonotonicInstant,
) -> Result<FactoryCreateRealmResult, Error>
pub fn create_realm( &self, payload: CreateRealmRequest, ___deadline: MonotonicInstant, ) -> Result<FactoryCreateRealmResult, Error>
Creates a new test realm configured with the given parameters and overrides.
Returns a RealmProxy that the client can use to start and introspect the realm.